==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/nl.js <==
/**
 * Dutch
 */

$.Editable.LANGS['nl'] = {
  translation: {
    "Bold": "Vet",
    "Italic": "Schuin",
    "Underline": "Onderstreept",
    "Strikethrough": "Doorhalen",
    "Font Size": "Letter grootte",
    "Color": "Kleur",
    "Background Color": "Achtergrondkleur",
    "Text Color": "Tekstkleur",
    "Format Block": "Opmaak",
    "Normal": "Normaal",
    "Paragraph": "Paragraaf",
    "Code": "Code",
    "Quote": "Quote",
    "Heading 1": "Kop 1",
    "Heading 2": "Kop 2",
    "Heading 3": "Kop 3",
    "Heading 4": "Kop 4",
    "Heading 5": "Kop 5",
    "Heading 6": "Kop 6",
    "Alignment": "Uitlijning",
    "Align Left": "Links uitlijnen",
    "Align Center": "Centreren",
    "Align Right": "Rechts uitlijnen",
    "Justify": "Uitlijnen",
    "Numbered List": "Nummering",
    "Bulleted List": "Opsommingsteken",
    "Indent Less": "Inspringen verkleinen",
    "Indent More": "Inspringen vergroten",
    "Select All": "Alles selecteren",
    "Insert Link": "Hyperlink invoegen",
    "Insert Image": "Afbeelding invoegen",
    "Insert Video": "Video invoegen",
    "Undo": "Ongedaan maken",
    "Redo": "Opnieuw",
    "Show HTML": "HTML tonen",
    "Float Left": "Links",
    "Float None": "Geen",
    "Float Right": "Rechts",
    "Replace Image": "Vervang afbeelding",
    "Remove Image": "Afbeelding verwijderen",
    "Title": "Titel",
    "Insert image": "Afbeelding invoegen",
    "Drop image": "Drop afbeelding",
    "or click": "of klik op",
    "Enter URL": "URL invoeren",
    "Please wait!": "Even geduld aub!",
    "Are you sure? Image will be deleted.": "Weet je het zeker? Opname wordt verwijderd.",
    "UNLINK": "Link verwijderen",
    "Open in new tab": "Openen in nieuw tabblad",
    "Type something": "Typ iets",
    "Cancel": "Annuleren",
    "OK": "Ok\u00e9",
    "Manage images": "Beheren van beelden",
    "Delete": "Verwijder",
    "Font Family": "Lettertype",
    "Insert Horizontal Line": "Plaats horizontale lijn"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.2.tar.gz: django-froala-editor-0.8.2/froala_editor/static/froala_editor/js/langs/nl.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Dutch
 */

$.Editable.LANGS['nl'] = {
  translation: {
    "Bold": "Vet",
    "Italic": "Schuin",
    "Underline": "Onderstreept",
    "Strikethrough": "Doorhalen",
    "Font Size": "Letter grootte",
    "Color": "Kleur",
    "Background Color": "Achtergrondkleur",
    "Text Color": "Tekstkleur",
    "Format Block": "Opmaak",
    "Normal": "Normaal",
    "Paragraph": "Paragraaf",
    "Code": "Code",
    "Quote": "Quote",
    "Heading 1": "Kop 1",
    "Heading 2": "Kop 2",
    "Heading 3": "Kop 3",
    "Heading 4": "Kop 4",
    "Heading 5": "Kop 5",
    "Heading 6": "Kop 6",
    "Alignment": "Uitlijning",
    "Align Left": "Links uitlijnen",
    "Align Center": "Centreren",
    "Align Right": "Rechts uitlijnen",
    "Justify": "Uitlijnen",
    "Numbered List": "Nummering",
    "Bulleted List": "Opsommingsteken",
    "Indent Less": "Inspringen verkleinen",
    "Indent More": "Inspringen vergroten",
    "Select All": "Alles selecteren",
    "Insert Link": "Hyperlink invoegen",
    "Insert Image": "Afbeelding invoegen",
    "Insert Video": "Video invoegen",
    "Undo": "Ongedaan maken",
    "Redo": "Opnieuw",
    "Show HTML": "HTML tonen",
    "Float Left": "Links",
    "Float None": "Geen",
    "Float Right": "Rechts",
    "Replace Image": "Vervang afbeelding",
    "Remove Image": "Afbeelding verwijderen",
    "Title": "Titel",
    "Insert image": "Afbeelding invoegen",
    "Drop image": "Drop afbeelding",
    "or click": "of klik op",
    "Enter URL": "URL invoeren",
    "Please wait!": "Even geduld aub!",
    "Are you sure? Image will be deleted.": "Weet je het zeker? Opname wordt verwijderd.",
    "UNLINK": "Link verwijderen",
    "Open in new tab": "Openen in nieuw tabblad",
    "Type something": "Typ iets",
    "Cancel": "Annuleren",
    "OK": "Ok\u00e9",
    "Manage images": "Beheren van beelden",
    "Delete": "Verwijder",
    "Font Family": "Lettertype",
    "Insert Horizontal Line": "Plaats horizontale lijn",
    "Table": "Tabel",
    "Insert table": "Tabel invoegen",
    "Cell": "Cel",
    "Row": "Rij",
    "Column": "Kolom",
    "Delete table": "Verwijder tabel",
    "Insert cell before": "Voeg cel in voor",
    "Insert cell after": "Voeg cel in na",
    "Delete cell": "Verwijder cel",
    "Merge cells": "Cellen samenvoegen",
    "Horizontal split": "Horizontaal splitsen",
    "Vertical split": "Verticaal splitsen",
    "Insert row above": "Voeg rij boven toe",
    "Insert row below": "Voeg rij onder toe",
    "Delete row": "Verwijder rij",
    "Insert column before": "Voeg kolom in voor",
    "Insert column after": "Voeg kolom in na",
    "Delete column": "Verwijder kolom"
  },
  direction: "ltr"
};
